# To-Do List

## To Be Evaluated

- [ ] Use Rust for better processing
- [ ] Process of more files than just Python ones (e.g. `.txt`, `.toml`, other langs)
- [ ] Create detail page for classes with docstring and listing class constants and methods
- [ ] Create detail page for functions with docstring and body detail

## To Do

- [ ] Handle `.github` files such as guidelines (`TODO`, `CONTRIBUTING`, ...)
- [ ] Provide an "exclude" config for files/dirs to ignore
- [ ] Insert `tags` for `.md` based on their names/contexts
- [ ] Get and list all metrics of statements featured

## Done

- [x] Migrate dependency system to use [uv](https://docs.astral.sh/uv/)
- [x] Process 100% of Python [AST](https://docs.python.org/3/library/ast.html)'s nodes on `mosheh.handlers.python`
- [x] Check for files docstrings and write below filepath
- [x] Accept structured file (e.g. `mosheh.json`) as parameters replacement
